]> granicus.if.org Git - procps-ng/commitdiff
top: normalize 2 former SUSE only out-of-memory fields
authorJim Warner <james.warner@comcast.net>
Fri, 15 Apr 2016 05:00:00 +0000 (00:00 -0500)
committerCraig Small <csmall@enc.com.au>
Sat, 16 Apr 2016 23:12:02 +0000 (09:12 +1000)
Now that the conditional OOMEM_ENABLE has been removed
and all users exposed to those 'out of memory' fields,
it's about time we added them to the top man document.

But before doing so, it's long past time that they are
normalized to at last remedy this kind of foolishness:

. excessive width on that oomem score itself (8 vs. 4)
. some potentially confusing names inherited from suse

Reference(s):
. removal of misguided OOMEM_ENABLE
commit 64238730fa45e92bc40b2aa28d107c2469ac29e9

Signed-off-by: Jim Warner <james.warner@comcast.net>
top/top.1
top/top.c
top/top_nls.c

index 562b10a97455abb5d2c7a1d403a13a8dc290d035..abe43922c58b027423f7ddc7d5d3584eedee1751 100644 (file)
--- a/top/top.1
+++ b/top/top.1
@@ -742,7 +742,19 @@ Zero in this field simply means priority will not be adjusted in determining
 a task's dispatch-ability.
 
 .TP 4
-14.\fB P \*(Em Last used \*(PU (SMP) \fR
+14.\fB OOMa \*(Em Out of Memory Adjustment Factor \fR
+The value, ranging from -1000 to +1000, added to the current out of memory
+score (OOMs) which is then used to determine which task to kill when memory
+is exhausted.
+
+.TP 4
+15.\fB OOMs \*(Em Out of Memory Score \fR
+The value, ranging from 0 to +1000, used to select task(s) to kill when memory
+is exhausted.
+Zero translates to `never kill' whereas 1000 means `always kill'.
+
+.TP 4
+16.\fB P \*(Em Last used \*(PU (SMP) \fR
 A number representing the last used processor.
 In a true SMP environment this will likely change frequently since the kernel
 intentionally uses weak affinity.
@@ -751,7 +763,7 @@ processes to change \*(PUs more often (because of the extra demand for
 \*(Pu time).
 
 .TP 4
-15.\fB PGRP \*(Em Process Group Id \fR
+17.\fB PGRP \*(Em Process Group Id \fR
 Every process is member of a unique process group which is used for
 distribution of signals and by terminals to arbitrate requests for their
 input and output.
@@ -761,7 +773,7 @@ By convention, this value equals the process ID (\*(Xa PID) of the first
 member of a process group, called the process group leader.
 
 .TP 4
-16.\fB PID \*(Em Process Id \fR
+18.\fB PID \*(Em Process Id \fR
 The task's unique process ID, which periodically wraps, though never
 restarting at zero.
 In kernel terms, it is a dispatchable entity defined by a task_struct.
@@ -772,11 +784,11 @@ a thread group ID for the thread group leader (\*(Xa TGID);
 and a TTY process group ID for the process group leader (\*(Xa TPGID).
 
 .TP 4
-17.\fB PPID \*(Em Parent Process Id \fR
+19.\fB PPID \*(Em Parent Process Id \fR
 The process ID (pid) of a task's parent.
 
 .TP 4
-18.\fB PR \*(Em Priority \fR
+20.\fB PR \*(Em Priority \fR
 The scheduling priority of the task.
 If you see `rt' in this field, it means the task is running
 under real time scheduling priority.
@@ -786,7 +798,7 @@ the operating itself was not preemptible.
 And while the 2.6 kernel can be made mostly preemptible, it is not always so.
 
 .TP 4
-19.\fB RES \*(Em Resident Memory Size (KiB) \fR
+21.\fB RES \*(Em Resident Memory Size (KiB) \fR
 A subset of the virtual address space (VIRT) representing the non-swapped
 \*(MP a task is currently using.
 It is also the sum of the RSan, RSfd and RSsh fields.
@@ -801,35 +813,35 @@ modified, act as a dedicated \*(MS and thus will never impact SWAP.
 \*(XX.
 
 .TP 4
-20.\fB RSan \*(Em Resident Anonymous Memory Size (KiB) \fR
+22.\fB RSan \*(Em Resident Anonymous Memory Size (KiB) \fR
 A subset of resident memory (RES) representing private pages not
 mapped to a file.
 
 .TP 4
-21.\fB RSfd \*(Em Resident File-Backed Memory Size (KiB) \fR
+23.\fB RSfd \*(Em Resident File-Backed Memory Size (KiB) \fR
 A subset of resident memory (RES) representing the implicitly shared
 pages supporting program images and shared libraries.
 It also includes explicit file mappings, both private and shared.
 
 .TP 4
-22.\fB RSlk \*(Em Resident Locked Memory Size (KiB) \fR
+24.\fB RSlk \*(Em Resident Locked Memory Size (KiB) \fR
 A subset of resident memory (RES) which cannot be swapped out.
 
 .TP 4
-23.\fB RSsh \*(Em Resident Shared Memory Size (KiB) \fR
+25.\fB RSsh \*(Em Resident Shared Memory Size (KiB) \fR
 A subset of resident memory (RES) representing the explicitly shared
 anonymous shm*/mmap pages.
 
 .TP 4
-24.\fB RUID \*(Em Real User Id \fR
+26.\fB RUID \*(Em Real User Id \fR
 The\fI real\fR user ID.
 
 .TP 4
-25.\fB RUSER \*(Em Real User Name \fR
+27.\fB RUSER \*(Em Real User Name \fR
 The\fI real\fR user name.
 
 .TP 4
-26.\fB S \*(Em Process Status \fR
+28.\fB S \*(Em Process Status \fR
 The status of the task which can be one of:
     \fBD\fR = uninterruptible sleep
     \fBR\fR = running
@@ -844,7 +856,7 @@ Even without a true SMP machine, you may see numerous tasks in this state
 depending on \*(We's delay interval and nice value.
 
 .TP 4
-27.\fB SHR \*(Em Shared Memory Size (KiB) \fR
+29.\fB SHR \*(Em Shared Memory Size (KiB) \fR
 A subset of resident memory (RES) that may be used by other processes.
 It will include shared anonymous pages and shared file-backed pages.
 It also includes private pages mapped to files representing
@@ -853,7 +865,7 @@ program images and shared libraries.
 \*(XX.
 
 .TP 4
-28.\fB SID \*(Em Session Id \fR
+30.\fB SID \*(Em Session Id \fR
 A session is a collection of process groups (\*(Xa PGRP),
 usually established by the login shell.
 A newly forked process joins the session of its creator.
@@ -862,11 +874,11 @@ member of the session, called the session leader, which is usually the
 login shell.
 
 .TP 4
-29.\fB SUID \*(Em Saved User Id \fR
+31.\fB SUID \*(Em Saved User Id \fR
 The\fI saved\fR user ID.
 
 .TP 4
-30.\fB SUPGIDS \*(Em Supplementary Group IDs \fR
+32.\fB SUPGIDS \*(Em Supplementary Group IDs \fR
 The IDs of any supplementary group(s) established at login or
 inherited from a task's parent.
 They are displayed in a comma delimited list.
@@ -879,7 +891,7 @@ Even so, such variable width fields could still suffer truncation.
 any truncated data.
 
 .TP 4
-31.\fB SUPGRPS \*(Em Supplementary Group Names \fR
+33.\fB SUPGRPS \*(Em Supplementary Group Names \fR
 The names of any supplementary group(s) established at login or
 inherited from a task's parent.
 They are displayed in a comma delimited list.
@@ -892,24 +904,24 @@ Even so, such variable width fields could still suffer truncation.
 any truncated data.
 
 .TP 4
-32.\fB SUSER \*(Em Saved User Name \fR
+34.\fB SUSER \*(Em Saved User Name \fR
 The\fI saved\fR user name.
 
 .TP 4
-33.\fB SWAP \*(Em Swapped Size (KiB) \fR
+35.\fB SWAP \*(Em Swapped Size (KiB) \fR
 The formerly resident portion of a task's address space written
 to the \*(MS when \*(MP becomes over committed.
 
 \*(XX.
 
 .TP 4
-34.\fB TGID \*(Em Thread Group Id \fR
+36.\fB TGID \*(Em Thread Group Id \fR
 The ID of the thread group to which a task belongs.
 It is the PID of the thread group leader.
 In kernel terms, it represents those tasks that share an mm_struct.
 
 .TP 4
-35.\fB TIME \*(Em \*(PU Time \fR
+37.\fB TIME \*(Em \*(PU Time \fR
 Total \*(PU time the task has used since it started.
 When Cumulative mode is \*O, each process is listed with the \*(Pu
 time that it and its dead children have used.
@@ -917,19 +929,19 @@ You toggle Cumulative mode with `S', which is both a \*(CO and an \*(CI.
 \*(XC `S' \*(CI for additional information regarding this mode.
 
 .TP 4
-36.\fB TIME+ \*(Em \*(PU Time, hundredths \fR
+38.\fB TIME+ \*(Em \*(PU Time, hundredths \fR
 The same as TIME, but reflecting more granularity through hundredths
 of a second.
 
 .TP 4
-37.\fB TPGID \*(Em Tty Process Group Id \fR
+39.\fB TPGID \*(Em Tty Process Group Id \fR
 The process group ID of the foreground process for the connected tty,
 or \-1 if a process is not connected to a terminal.
 By convention, this value equals the process ID (\*(Xa PID) of the
 process group leader (\*(Xa PGRP).
 
 .TP 4
-38.\fB TTY \*(Em Controlling Tty \fR
+40.\fB TTY \*(Em Controlling Tty \fR
 The name of the controlling terminal.
 This is usually the device (serial port, pty, etc.) from which the
 process was started, and which it uses for input or output.
@@ -937,22 +949,22 @@ However, a task need not be associated with a terminal, in which case
 you'll see `?' displayed.
 
 .TP 4
-39.\fB UID \*(Em User Id \fR
+41.\fB UID \*(Em User Id \fR
 The\fI effective\fR user ID of the task's owner.
 
 .TP 4
-40.\fB USED \*(Em Memory in Use (KiB) \fR
+42.\fB USED \*(Em Memory in Use (KiB) \fR
 This field represents the non-swapped \*(MP a task is using (RES) plus
 the swapped out portion of its address space (SWAP).
 
 \*(XX.
 
 .TP 4
-41.\fB USER \*(Em User Name \fR
+43.\fB USER \*(Em User Name \fR
 The\fI effective\fR user name of the task's owner.
 
 .TP 4
-42.\fB VIRT \*(Em Virtual Memory Size (KiB) \fR
+44.\fB VIRT \*(Em Virtual Memory Size (KiB) \fR
 The total amount of \*(MV used by the task.
 It includes all code, data and shared libraries plus pages that have been
 swapped out and pages that have been mapped but not used.
@@ -960,20 +972,20 @@ swapped out and pages that have been mapped but not used.
 \*(XX.
 
 .TP 4
-43.\fB WCHAN \*(Em Sleeping in Function \fR
+45.\fB WCHAN \*(Em Sleeping in Function \fR
 This field will show the name of the kernel function in which the task
 is currently sleeping.
 Running tasks will display a dash (`\-') in this column.
 
 .TP 4
-44.\fB nDRT \*(Em Dirty Pages Count \fR
+46.\fB nDRT \*(Em Dirty Pages Count \fR
 The number of pages that have been modified since they were last
 written to \*(AS.
 Dirty pages must be written to \*(AS before the corresponding physical
 memory location can be used for some other virtual page.
 
 .TP 4
-45.\fB nMaj \*(Em Major Page Fault Count \fR
+47.\fB nMaj \*(Em Major Page Fault Count \fR
 The number of\fB major\fR page faults that have occurred for a task.
 A page fault occurs when a process attempts to read from or write to a
 virtual page that is not currently present in its address space.
@@ -981,7 +993,7 @@ A major page fault is when \*(AS access is involved in making that
 page available.
 
 .TP 4
-46.\fB nMin \*(Em Minor Page Fault count \fR
+48.\fB nMin \*(Em Minor Page Fault count \fR
 The number of\fB minor\fR page faults that have occurred for a task.
 A page fault occurs when a process attempts to read from or write to a
 virtual page that is not currently present in its address space.
@@ -989,50 +1001,50 @@ A minor page fault does not involve \*(AS access in making that
 page available.
 
 .TP 4
-47.\fB nTH \*(Em Number of Threads \fR
+48.\fB nTH \*(Em Number of Threads \fR
 The number of threads associated with a process.
 
 .TP 4
-48.\fB nsIPC \*(Em IPC namespace \fR
+50.\fB nsIPC \*(Em IPC namespace \fR
 The Inode of the namespace used to isolate interprocess communication (IPC)
 resources such as System V IPC objects and POSIX message queues.
 
 .TP 4
-49.\fB nsMNT \*(Em MNT namespace \fR
+51.\fB nsMNT \*(Em MNT namespace \fR
 The Inode of the namespace used to isolate filesystem mount points thus
 offering different views of the filesystem hierarchy.
 
 .TP 4
-50.\fB nsNET \*(Em NET namespace \fR
+52.\fB nsNET \*(Em NET namespace \fR
 The Inode of the namespace used to isolate resources such as network devices,
 IP addresses, IP routing, port numbers, etc.
 
 .TP 4
-51.\fB nsPID \*(Em PID namespace \fR
+53.\fB nsPID \*(Em PID namespace \fR
 The Inode of the namespace used to isolate process ID numbers
 meaning they need not remain unique.
 Thus, each such namespace could have its own `init/systemd' (PID #1) to
 manage various initialization tasks and reap orphaned child processes.
 
 .TP 4
-52.\fB nsUSER \*(Em USER namespace \fR
+54.\fB nsUSER \*(Em USER namespace \fR
 The Inode of the namespace used to isolate the user and group ID numbers.
 Thus, a process could have a normal unprivileged user ID outside a user
 namespace while having a user ID of 0, with full root privileges, inside
 that namespace.
 
 .TP 4
-53.\fB nsUTS \*(Em UTS namespace \fR
+55.\fB nsUTS \*(Em UTS namespace \fR
 The Inode of the namespace used to isolate hostname and NIS domain name.
 UTS simply means "UNIX Time-sharing System".
 
 .TP 4
-54.\fB vMj \*(Em Major Page Fault Count Delta\fR
+56.\fB vMj \*(Em Major Page Fault Count Delta\fR
 The number of\fB major\fR page faults that have occurred since the
 last update (see nMaj).
 
 .TP 4
-55.\fB vMn \*(Em Minor Page Fault Count Delta\fR
+57.\fB vMn \*(Em Minor Page Fault Count Delta\fR
 The number of\fB minor\fR page faults that have occurred since the
 last update (see nMin).
 
index c857f87ea9384c7aa2a658833de647724cf92e0e..29202e402f3edf1177b3ba8e4fc7e26c5a02bfa8 100644 (file)
--- a/top/top.c
+++ b/top/top.c
@@ -1556,8 +1556,8 @@ static struct {
    {    -1,     -1,  A_left,     -1,  PROCPS_PIDS_SUPGIDS       },  // str      EU_SGD
    {    -1,     -1,  A_left,     -1,  PROCPS_PIDS_SUPGROUPS     },  // str      EU_SGN
    {     0,     -1,  A_right,    -1,  PROCPS_PIDS_ID_TGID       },  // s_int    EU_TGD
-   {     3,     -1,  A_right,    -1,  PROCPS_PIDS_OOM_ADJ       },  // s_int    EU_OOA
-   {     8,     -1,  A_right,    -1,  PROCPS_PIDS_OOM_SCORE     },  // s_int    EU_OOM
+   {     5,     -1,  A_right,    -1,  PROCPS_PIDS_OOM_ADJ       },  // s_int    EU_OOA
+   {     4,     -1,  A_right,    -1,  PROCPS_PIDS_OOM_SCORE     },  // s_int    EU_OOM
    {    -1,     -1,  A_left,     -1,  PROCPS_PIDS_ENVIRON       },  // str      EU_ENV
    {     3,     -1,  A_right,    -1,  PROCPS_PIDS_FLT_MAJ_DELTA },  // ul_int   EU_FV1
    {     3,     -1,  A_right,    -1,  PROCPS_PIDS_FLT_MIN_DELTA },  // ul_int   EU_FV2
index 3e25c746a2474b346feec49ed28835370bedabe2..39ab5fdce7f3b0563f1eee5b68dc7af5fc57b05f 100644 (file)
@@ -237,12 +237,12 @@ static void build_two_nlstabs (void) {
 /* Translation Hint: maximum 'TGID' = 5 */
    Head_nlstab[EU_TGD] = _("TGID");
    Desc_nlstab[EU_TGD] = _("Thread Group Id");
-/* Translation Hint: maximum 'Adj' = 3 */
-   Head_nlstab[EU_OOA] = _("Adj");
-   Desc_nlstab[EU_OOA] = _("oom_adjustment (2^X)");
-/* Translation Hint: maximum 'Badness' = 7 */
-   Head_nlstab[EU_OOM] = _("Badness");
-   Desc_nlstab[EU_OOM] = _("oom_score (badness)");
+/* Translation Hint: maximum 'OOMa' = 5 */
+   Head_nlstab[EU_OOA] = _("OOMa");
+   Desc_nlstab[EU_OOA] = _("OOMEM Adjustment");
+/* Translation Hint: maximum 'OOMs' = 4 */
+   Head_nlstab[EU_OOM] = _("OOMs");
+   Desc_nlstab[EU_OOM] = _("OOMEM Score current");
 /* Translation Hint: maximum 'ENVIRON' = 7 */
    Head_nlstab[EU_ENV] = _("ENVIRON");
 /* Translation Hint: the abbreviation 'vars' below is shorthand for